# .github/PULL_REQUEST_TEMPLATE/dependency_update.md
## Dependency Update

<!-- This PR was automatically created by Dependabot -->

### Updated Dependencies
<!-- List of updated dependencies -->
- 

### Type of change
- [ ] Security update
- [ ] Bug fix update
- [ ] Feature update
- [ ] Breaking change

### Changelog/Release Notes
<!-- Add any relevant changelog entries or release notes links -->

### Testing Notes
- [ ] All tests pass with the updated dependencies
- [ ] No new warnings or deprecation notices
- [ ] No breaking changes identified

### Risk Assessment
<!-- Low/Medium/High - Explain why -->

### Additional Notes
<!-- Any other relevant information -->